@@ -1,15 +1,14 @@
 
 import requests
-import os
 import json
+from generalpackager import PACKAGER_GITHUB_API
 
 
 class GitHub:
     """ Tools to interface a GitHub Repository. """
-    def __init__(self, name, owner="ManderaGeneral", token=None):
+    def __init__(self, name, owner="ManderaGeneral"):
         self.name = name
         self.owner = owner
-        self.token = os.environ['packager_github_api'] if token is None else token
 
         self.assert_url_up()  # Checks name, owner and token all in one
 
@@ -67,7 +66,7 @@ class GitHub:
 
         kwargs = {
             "headers": {"Accept": "application/vnd.github.mercy-preview+json"},
-            "auth": (self.owner, self.token),
+            "auth": (self.owner, PACKAGER_GITHUB_API.value),
         }
         if data:
             kwargs["data"] = json.dumps(data)
