@@ -1,14 +1,14 @@
 
 from generalfile import Path
+from generalpackager import GIT_PASSWORD
+
 from setuptools import find_namespace_packages
 import re
 from git import Repo
-import os
 
 
 class LocalRepo:
     """ Tools to help Path interface a Local Python Repository. """
-
     name = ...
     version = ...
     description = ...
@@ -18,10 +18,12 @@ class LocalRepo:
 
     metadata_keys = [key for key, value in locals().items() if value is Ellipsis]
 
-    def __init__(self, path):
+    def __init__(self, path, git_exclude_lines):
         assert self.path_is_repo(path=path)
 
         self.path = Path(path).absolute()
+        self.git_exclude_lines = git_exclude_lines
+
         self.name = self.path.parts()[-1]
 
         for key, value in self.get_metadata_path().read().items():
@@ -35,6 +37,10 @@ class LocalRepo:
             if getattr(self, key) is Ellipsis:
                 raise AssertionError(f"Key '{key}' for {self}'s metadata is still {Ellipsis}")
 
+        if self.extras_require:
+            self.extras_require["full"] = list(set().union(*self.extras_require.values()))
+            self.extras_require["full"].sort()
+
     def metadata_setter(self, value, key):
         """ Set a metadata's key both in instance and json file. """
         if value != getattr(self, f"_{key}"):
@@ -68,6 +74,10 @@ class LocalRepo:
         """ Get a Path instance pointing to workflow.yml, regardless if it exists. """
         return self.path / ".github/workflows/workflow.yml"
 
+    def get_test_main_path(self):
+        """ Get a Path instance pointing to workflow.yml, regardless if it exists. """
+        return self.path / f"{self.name}/test/main.py"
+
     def get_package_paths(self):
         """ Get a list of Paths pointing to each folder containing a Python file in this local repo, aka `namespace package`. """
         return [self.path / pkg.replace(".", "/") for pkg in find_namespace_packages(where=str(self.path))]
@@ -94,12 +104,13 @@ class LocalRepo:
             :rtype: dict[list[str]] """
         todos = []
         for path in self.path.get_paths_recursive():
+            if path.name().lower() in ("shelved.patch", "readme.md") or any([exclude in path for exclude in self.git_exclude_lines]):
+                continue
+
             try:
                 text = path.text.read()
             except:
                 continue
-            if path.name().lower() in ("shelved.patch", "readme.md"):
-                continue
 
             for todo in re.findall("todo+: (.+)", text, re.I):
                 todos.append({
@@ -114,21 +125,12 @@ class LocalRepo:
             message = "Automatic commit."
 
         repo = Repo(str(self.path))
-
-        # files = [str(path.relative()) for path in self.path.get_paths_recursive() if not any([string in path for string in (".git", ".idea", "__pycache__")])]
-        # print(files)
-        # repo.index.add(files)
-
-        # print(repo.index.)
-
         repo.git.add(A=True)
         repo.index.commit(message=message)
         remote = repo.remote()
-        remote.set_url(f"https://Mandera:{os.environ['packager_github_api']}@github.com/ManderaGeneral/generalpackager.git")
+        remote.set_url(f"https://Mandera:{GIT_PASSWORD}@github.com/ManderaGeneral/{self.name}.git")
         remote.push()
 
-        # remote.set_url("")
-
     def bump_version(self):
         """ Bump micro version in metadata.json. """
         parts = self.version.split(".")
