@@ -24,20 +24,26 @@ class Packager(_PackagerMarkdown, _PackagerGitHub, _PackagerFiles, _PackagerMeta
     email = "rickard.abraham@gmail.com"
     license = "mit"
     python = "3.8", "3.9"  # Only supports basic definition with tuple of major.minor
-    os = "windows", "macos", "ubuntu"
+    os = "windows", "ubuntu"
+    # os = "windows", "macos", "ubuntu"
 
-    git_exclude_lines = "/.idea/",
+    git_exclude_lines = ".idea", "build", "dist", "*.egg-info", "__pycache__", ".git"
 
     def __init__(self, name, repos_path=None, commit_sha="master"):
-        if repos_path is None:
-            repos_path = Path().absolute().get_parent()
+        repos_path = Path(repos_path).absolute()
+        while not LocalRepo.get_local_repos(repos_path):
+            repos_path = repos_path.get_parent()
+
+        # print("Repo path view:")
+        # list(repos_path.get_paths_recursive(depth=4))
+        # repos_path.view()
 
         self.name = name
         self.repos_path = repos_path
         self.commit_sha = commit_sha
 
         self.github = GitHub(name=name)
-        self.localrepo = LocalRepo(path=repos_path / name)
+        self.localrepo = LocalRepo(path=repos_path / name, git_exclude_lines=self.git_exclude_lines)
         self.localmodule = LocalModule(module=importlib.import_module(name=name))
         self.pypi = PyPI(name=name)
 
@@ -51,13 +57,11 @@ class Packager(_PackagerMarkdown, _PackagerGitHub, _PackagerFiles, _PackagerMeta
         self.generate_license()
         self.generate_workflow()
 
-    def setup_all(self, message=None):
+    def sync_package(self, message=None):
         """ Called by GitHub Actions when a commit is pushed. """
-        self.localrepo.bump_version()
         self.generate_localfiles()
         self.sync_github_metadata()
         self.localrepo.commit_and_push(message=message)
-        self.upload()
 
 
 
