@@ -11,12 +11,13 @@ class _PackagerFiles:
             :param generalpackager.Packager self:
             :param path:
             :param text: """
-        path.text.write(text, overwrite=True)
+        path.text.write(f"{text}\n", overwrite=True)
 
     def generate_setup(self):
-        """ Generate setup.py and overwrite local repo.
+        """ Generate setup.py.
 
             :param generalpackager.Packager self: """
+        readme_path = self.localrepo.get_readme_path().relative(self.localrepo.path)
         last_version_split = self.python[-1].split(".")
         last_version_bumped_micro = f"{last_version_split[0]}.{int(last_version_split[1]) + 1}"
         setup_kwargs = {
@@ -25,7 +26,7 @@ class _PackagerFiles:
             "author_email": f'"{self.email}"',
             "version": f'"{self.localrepo.version}"',
             "description": f'"{self.localrepo.description}"',
-            "long_description": f"Path(r'{self.localrepo.get_readme_path().relative()}').read_text(encoding='utf-8')",
+            "long_description": f"Path(r'{readme_path}').read_text(encoding='utf-8')",
             "long_description_content_type": '"text/markdown"',
             "install_requires": self.localrepo.install_requires,
             "url": f'"{self.github.url()}"',
@@ -42,17 +43,22 @@ class _PackagerFiles:
 
         setup = top.add(CodeLine("setup("))
         for key, value in setup_kwargs.items():
-            if isinstance(value, list):
+            if isinstance(value, list) and value:
                 list_ = setup.add(CodeLine(f"{key}=["))
                 for item in value:
                     list_.add(CodeLine(f"'{item}',"))
                 setup.add(CodeLine("],"))
+            elif isinstance(value, dict) and value:
+                dict_ = setup.add(CodeLine(f"{key}={{"))
+                for k, v in value.items():
+                    dict_.add(CodeLine(f"'{k}': {v},"))
+                setup.add(CodeLine("},"))
             else:
                 setup.add(CodeLine(f"{key}={value},"))
 
-        top.add(CodeLine(")", space_after=1))
+        top.add(CodeLine(")"))
 
-        self.generate_file(self.localrepo.get_setup_path(), top.text(watermark=False))
+        self.generate_file(self.localrepo.get_setup_path(), top.text())
 
     def generate_git_exclude(self):
         """ Generate git exclude file.
@@ -84,5 +90,7 @@ class _PackagerFiles:
 
         jobs = workflow.add("jobs:")
         jobs.add(self.get_unittest_job())
+        jobs.add(self.get_sync_and_publish_job())
+
+        self.generate_file(self.localrepo.get_workflow_path(), workflow.text())
 
-        self.localrepo.get_workflow_path().text.write(workflow.text(), overwrite=True)
